@@ -3,10 +3,10 @@
 #include "plugin.h"
 
 char*
-pdf_page_get_text(zathura_page_t* page, PopplerPage* poppler_page,
+pdf_page_get_text(zathura_page_t* page, void* data,
     zathura_rectangle_t rectangle, zathura_error_t* error)
 {
-  if (page == NULL || poppler_page == NULL) {
+  if (page == NULL || data == NULL) {
     if (error != NULL) {
       *error = ZATHURA_ERROR_INVALID_ARGUMENTS;
     }
@@ -19,6 +19,7 @@ pdf_page_get_text(zathura_page_t* page, PopplerPage* poppler_page,
     .y1 = rectangle.y1,
     .y2 = rectangle.y2
   };
+  PopplerPage* poppler_page = data;
 
   /* get selected text */
   return poppler_page_get_selected_text(poppler_page, POPPLER_SELECTION_GLYPH, &rect);
